@@ -26,6 +26,29 @@ class EssClient(AbstractClient):
     _service = 'ess'
 
 
+    def BindEmployeeUserIdWithClientOpenId(self, request):
+        """将电子签系统员工userId与客户系统员工openId进行绑定
+
+        :param request: Request instance for BindEmployeeUserIdWithClientOpenId.
+        :type request: :class:`tencentcloud.ess.v20201111.models.BindEmployeeUserIdWithClientOpenIdRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.BindEmployeeUserIdWithClientOpenIdResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BindEmployeeUserIdWithClientOpenId", params, headers=headers)
+            response = json.loads(body)
+            model = models.BindEmployeeUserIdWithClientOpenIdResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CancelFlow(self, request):
         """用于撤销签署流程
         适用场景：如果某个合同流程当前至少还有一方没有签署，则可通过该接口取消该合同流程。常用于合同发错、内容填错，需要及时撤销的场景。
@@ -75,8 +98,9 @@ class EssClient(AbstractClient):
 
 
     def CreateBatchCancelFlowUrl(self, request):
-        """电子签企业版：指定需要批量撤回的签署流程Id，获取批量撤销链接
-        客户指定需要撤回的签署流程Id，最多100个，超过100不处理；接口调用成功返回批量撤回合同的链接，通过链接跳转到电子签小程序完成批量撤回
+        """注：此接口建会废弃，请使用撤销单个签署流程（CancelFlow）接口。
+        指定需要批量撤回的签署流程Id，获取批量撤销链接。
+        客户指定需要撤回的签署流程Id，最多100个，超过100不处理；接口调用成功返回批量撤回合同的链接，通过链接跳转到电子签小程序完成批量撤回。
 
         :param request: Request instance for CreateBatchCancelFlowUrl.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateBatchCancelFlowUrlRequest`
@@ -302,7 +326,7 @@ class EssClient(AbstractClient):
 
 
     def CreateFlowSignUrl(self, request):
-        """创建签署链接，请联系客户经理申请使用
+        """创建集成页面签署链接，请联系客户经理申请使用
 
         :param request: Request instance for CreateFlowSignUrl.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowSignUrlRequest`
@@ -348,7 +372,7 @@ class EssClient(AbstractClient):
 
 
     def CreateIntegrationUserRoles(self, request):
-        """集成版绑定员工角色
+        """绑定员工与对应角色
 
         :param request: Request instance for CreateIntegrationUserRoles.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateIntegrationUserRolesRequest`
@@ -467,7 +491,7 @@ class EssClient(AbstractClient):
 
 
     def CreateSchemeUrl(self, request):
-        """获取小程序跳转链接
+        """获取小程序签署链接
 
         适用场景：如果需要签署人在自己的APP、小程序、H5应用中签署，可以通过此接口获取跳转腾讯电子签小程序的签署跳转链接。
 
@@ -569,7 +593,7 @@ class EssClient(AbstractClient):
 
 
     def DeleteIntegrationRoleUsers(self, request):
-        """解绑用户角色绑定关系
+        """解绑员工与对应角色关系
 
         :param request: Request instance for DeleteIntegrationRoleUsers.
         :type request: :class:`tencentcloud.ess.v20201111.models.DeleteIntegrationRoleUsersRequest`
@@ -734,7 +758,7 @@ class EssClient(AbstractClient):
 
 
     def DescribeIntegrationEmployees(self, request):
-        """查询员工信息，每次返回的数据量最大为20
+        """查询企业员工列表，每次返回的数据量最大为20
 
         :param request: Request instance for DescribeIntegrationEmployees.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationEmployeesRequest`
@@ -780,7 +804,7 @@ class EssClient(AbstractClient):
 
 
     def DescribeIntegrationRoles(self, request):
-        """查询集成版角色
+        """查询企业角色列表
 
         :param request: Request instance for DescribeIntegrationRoles.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationRolesRequest`
@@ -991,8 +1015,31 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UnbindEmployeeUserIdWithClientOpenId(self, request):
+        """将存在绑定关系的电子签系统员工userId与客户系统员工openId进行解绑
+
+        :param request: Request instance for UnbindEmployeeUserIdWithClientOpenId.
+        :type request: :class:`tencentcloud.ess.v20201111.models.UnbindEmployeeUserIdWithClientOpenIdRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.UnbindEmployeeUserIdWithClientOpenIdResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UnbindEmployeeUserIdWithClientOpenId", params, headers=headers)
+            response = json.loads(body)
+            model = models.UnbindEmployeeUserIdWithClientOpenIdResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateIntegrationEmployees(self, request):
-        """更新集成版员工信息(姓名，手机号，邮件)，用户实名后无法更改姓名与手机号
+        """更新员工信息(姓名，手机号，邮件)，用户实名后无法更改姓名与手机号
 
         :param request: Request instance for UpdateIntegrationEmployees.
         :type request: :class:`tencentcloud.ess.v20201111.models.UpdateIntegrationEmployeesRequest`
